// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Stats GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_Stats))
{
	CRPG_Stats.delete();
}

exec($CRPG_C::Path @ "guis/stats.gui");

// Clear
CRPG_Avatar.setEmpty();

// Name
CRPG_Avatar.dynamicObject = "fffObject";

// Object Creation and Sequences
CRPG_Avatar.setObject(CRPG_Avatar.dynamicObject, "base/data/shapes/player/m.dts", "", 0);

// ============================================================
// Section 2 : Functions
// ============================================================
function adjustCityRPGStats()
{
	// Fiscal
	CRPG_Stats_OnHand.setValue("$" @ MyCityRPGDatum.var["MONEY"]);
	CRPG_Stats_InBank.setValue("$" @ MyCityRPGDatum.var["BANK"]);
	CRPG_Stats_InDebt.setValue((MyCityRPGDatum.var["DEBT"] ? "<color:ff0000>" : "") @ "$" @ MyCityRPGDatum.var["DEBT"]);
	CRPG_Stats_Networth.setValue("$" @ (MyCityRPGDatum.var["BANK"] + MyCityRPGDatum.var["MONEY"] - MyCityRPGDatum.var["DEBT"]));
	
	// Job
	CRPG_Stats_Job.setValue("<just:center>" @ MyCityRPGDatum.var["JOBNAME"]);
	CRPG_Stats_TicksDue.setValue("<just:center>" @ (MyCityRPGDatum.var["WORKHOURS"] ? MyCityRPGDatum.var["WORKHOURS"] SPC "Hours Due" : ""));
	CRPG_Stats_Plastic.setValue("<just:center>" @ MyCityRPGDatum.var["PLASTIC"] SPC "Chunks");
	CRPG_Stats_RefPlastic.setValue("<just:center>" @ MyCityRPGDatum.var["REFPLASTIC"] SPC "Plastic");
	
	// Education
	CRPG_Stats_Education.setValue("<just:center>Tier" SPC MyCityRPGDatum.var["EDUCATION"] SPC "Diploma");
	CRPG_Stats_Student.setValue("<just:center>" @ (MyCityRPGDatum.var["STUDENT"] ? "Enrolled" : "Not Enrolled"));
	CRPG_Stats_Reincarnate.setValue("<just:center>" @ MyCityRPGDatum.var["REINCARNATE"] ? "You're a Reincarnate!" : "");
	
	// EXP
	CRPG_Stats_Bum.setValue("Lvl." SPC MyCityRPGDatum.var["expBum"]);
	CRPG_Stats_Drone.setValue("Lvl." SPC MyCityRPGDatum.var["expDrone"]);
	CRPG_Stats_Labor.setValue("Lvl." SPC MyCityRPGDatum.var["expLabor"]);
	CRPG_Stats_Shopkeep.setValue("Lvl." SPC MyCityRPGDatum.var["expStore"]);
	CRPG_Stats_Law.setValue("Lvl." SPC MyCityRPGDatum.var["expLaw"]);
	CRPG_Stats_Political.setValue("Lvl." SPC MyCityRPGDatum.var["expPC"]);
}

function CityRPG_openStats(%key)
{
	if($CRPG_C::Active)
	{
		if(%key)
		{
			canvas.pushDialog(CRPG_Stats);
		}
	}
}

function CRPG_Stats::adjustAvatar(%gui)
{
	CRPG_Avatar.setSequence(CRPG_Avatar.dynamicObject, 0, "headup", 0);
	CRPG_Avatar.setSequence(CRPG_Avatar.dynamicObject, 1, "run", 0.85);
	CRPG_Avatar.setOrbitDist(4.34);
	CRPG_Avatar.setCameraRot(0.25, 0, 4.25);
	
	if(CRPG_Avatar.parts > 0)
	{
		%gui.hideAllNodes();
		%gui.adjustAvatarNodes();
		%gui.adjustAvatarColors();
	}
	else
	{
		%gui.applyDefaultPrefs();
	}
}

function CRPG_Stats::adjustAvatarColors(%gui)
{
	if(CRPG_Avatar.parts > 0)
	{
		CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, "headskin", $pref::Avatar::HeadColor);
		
		for(%i = 0; %i < CRPG_Avatar.parts; %i++)
		{
			%color = CRPG_Avatar.color[%i];
			
			if(%color $= "skin")
			{
				%color = $pref::Avatar::HeadColor;
			}
			
			CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, CRPG_Avatar.part[%i], %color);
		}
	}
}

function CRPG_Stats::adjustAvatarNodes(%gui)
{
	CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, "headskin");
	
	if(CRPG_Avatar.parts > 0)
	{
		for(%i = 0; %i < CRPG_Avatar.parts; %i++)
		{
			CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, CRPG_Avatar.part[%i]);
		}
	}
	
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "face", getIflFrame("face", $Pref::Avatar::FaceName));
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "decal", getIflFrame("decal", CRPG_Avatar.decal));
}

function CRPG_Stats::applyDefaultPrefs(%gui)
{
	%gui.hideAllNodes();
	
	%nodeCount = 0;
	
	%node[%nodeCount++] = "headSkin" TAB "1 1 0 1";
	%node[%nodeCount++] = "chest" TAB "1 1 1 1";
	%node[%nodeCount++] = "LArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "RArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "LHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "RHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "pants" TAB "0 0 0.8 1";
	%node[%nodeCount++] = "LShoe" TAB "0.2 0.2 0.2 1";
	%node[%nodeCount++] = "RShoe" TAB "0.2 0.2 0.2 1";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, getField(%node[%i], 0));
		CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, getField(%node[%i], 0), getField(%node[%i], 1));
	}
	
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "face", 0);
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "decal", 0);
}

function CRPG_Stats::applyForJob(%gui)
{
	if(isObject(MyCityRPGDatum))
	{
		%id = CRPG_Stats_Jobs.getSelectedId();
		%text = CRPG_Stats_Jobs.getRowTextById(%id);
		
		if(%text !$= "")
		{
			%name = getField(%text, 1);
			%edu = getField(%text, 3);
			%id = getField(%text, 4);
			
			if(MyCityRPGDatum.var["Education"] >= %edu)
			{
				if(%cost > 0)
					MessageBoxOkCancel("You are about to be a" SPC %name, "Are you sure you want to spend $" @ %cost SPC "to apply for the job \"" @ %name @ "\"?\n\nThis cannot be undone and if you apply for another job you will not get that money back.", "commandToServer('Stats_ApplyForJob', " @ %id @ ");", "");
				else
					MessageBoxOkCancel("You are about to be a" SPC %name, "Are you sure you want to give up your current job for this new position?\n\nThink carefully.\nThis action cannot be undone.", "commandToServer('Stats_ApplyForJob', " @ %id @ ");", "");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "You are not educated enough for" SPC %name @ ".");
			}
		}
		else
		{
			MessageBoxOK("Does Not Compute", "Select a job in the upper right and then click this button to apply for it.\n\nIf no jobs are visible, you are currently in the only role you can play!");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Stats::hideAllNodes(%gui)
{
	%nodeCount = 0;
	
	%node[%nodeCount++] = "plume";
	%node[%nodeCount++] = "triPlume";
	%node[%nodeCount++] = "septPlume";
	%node[%nodeCount++] = "Visor";
	
	%node[%nodeCount++] = "helmet";
	%node[%nodeCount++] = "pointyHelmet";
	%node[%nodeCount++] = "flareHelmet";
	%node[%nodeCount++] = "scoutHat";
	%node[%nodeCount++] = "bicorn";
	%node[%nodeCount++] = "copHat";
	%node[%nodeCount++] = "knitHat";
	
	%node[%nodeCount++] = "chest";
	%node[%nodeCount++] = "femchest";
	
	%node[%nodeCount++] = "pants";
	%node[%nodeCount++] = "skirtHip";
	
	%node[%nodeCount++] = "armor";
	%node[%nodeCount++] = "bucket";
	%node[%nodeCount++] = "cape";
	%node[%nodeCount++] = "pack";
	%node[%nodeCount++] = "quiver";
	%node[%nodeCount++] = "tank";
	
	%node[%nodeCount++] = "epaulets";
	%node[%nodeCount++] = "epauletsRankA";
	%node[%nodeCount++] = "epauletsRankB";
	%node[%nodeCount++] = "epauletsRankC";
	%node[%nodeCount++] = "epauletsRankD";
	%node[%nodeCount++] = "ShoulderPads";
	
	%node[%nodeCount++] = "LArm";
	%node[%nodeCount++]  = "LArmSlim";
	
	%node[%nodeCount++]  = "LHand";
	%node[%nodeCount++]  = "LHook";
	
	%node[%nodeCount++]  = "RArm";
	%node[%nodeCount++]  = "RArmSlim";
	
	%node[%nodeCount++]  = "RHand";
	%node[%nodeCount++]  = "RHook";
	
	%node[%nodeCount++]  = "pants";
	%node[%nodeCount++]  = "skirtHip";
	
	%node[%nodeCount++]  = "LShoe";
	%node[%nodeCount++]  = "LPeg";
	
	%node[%nodeCount++]  = "RShoe";
	%node[%nodeCount++]  = "RPeg";
	
	%node[%nodeCount++]  = "SkirtTrimLeft";
	%node[%nodeCount++]  = "SkirtTrimRight";
	%node[%nodeCount++]  = "LSki";
	%node[%nodeCount++]  = "RSki";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		CRPG_Avatar.hideNode(CRPG_Avatar.dynamicObject, %node[%i]);
	}
}

function CRPG_Stats::onWake(%gui)
{
	%gui.setPane(0);
	
	if($CRPG_C::Active)
	{
		%gui.adjustAvatar();
		commandToServer('Stats_GetOutfit');
		commandToServer('Stats_GetJobs');
	}
}

function CRPG_Stats::setPane(%gui, %id)
{
	%id = mClamp(%id, 0, %id);
	
	if(%id < %gui.numPanes)
	{
		for(%a = 0; %a < %gui.numPanes; %a++)
		{
			if(%id == %a)
			{
				%gui.tab[%a].setBitmap("Add-Ons/Client_CityRPG/images/ui/Tab1use");
				%gui.pane[%a].setVisible(true);
			}
			else
			{
				%gui.tab[%a].setBitmap("Add-Ons/Client_CityRPG/images/ui/Tab1");
				%gui.pane[%a].setVisible(false);
			}
		}
	}
}

function CRPG_Stats::sortList(%gui, %list, %col)
{
	%list.sort(%col, %list.sort);
	%list.sort = !%list.sort;
	return %list.sort;
}

function CRPG_Stats::sortNumList(%gui, %list, %col)
{
	%list.sortNumerical(%col, %list.numSort);
	%list.numSort = !%list.numSort;
	return %list.numSort;
}

function getIflFrame(%node, %name)
{
	%file = "base/data/shapes/player/" @ %node @ ".ifl";
	
	if(isFile(%file))
	{
		%name = stripTrailingSpaces(fileBase(%name));
		
		if(%name !$= "")
		{
			%fo = new FileObject() {};
			%fo.openForRead(%file);
			
			%hasFound = false;
			%lineNum = 0;
			
			while(!%fo.isEOF())
			{
				%line = %fo.readLine();
				%thisDecal = stripTrailingSpaces(fileBase(%line));
				
				if(%thisDecal $= %name)
				{
					%hasFound = true;
					break;
				}
				else
				{
					%lineNum++;
				}
			}
			
			%fo.close();
			%fo.delete();
			
			if(%hasFound)
			{
				return %lineNum;
			}
			else
			{
				return 0;
			}
		}
		else
		{
			return 0;
		}
	}
	else
	{
		echo("\c2getIflFrame(\"" @ %node @ "\", \"" @ %name @ "\") : You did not supply a proper IFL file name to read from.");
		return 0;
	}
}

// ============================================================
// Section 3 : ClientCmds
// ============================================================
function clientCmdStats_SetJobs(%colors, %names, %costs, %edus, %ids)
{
	CRPG_Stats_Jobs.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%color = collapseEscape("\\c" @ mClamp(getField(%colors, %i), 0, 9));
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		%cost	= mFloor(%cost) > 0 ? "$" @ %cost : "None";
		%edu	= getField(%edus, %i);
		%id	= getField(%ids, %i);
		
		if(%name !$= "")
			CRPG_Stats_Jobs.addRow(CRPG_Stats_Jobs.rowCount(), %color TAB %name TAB %cost TAB %edu TAB %id);
	}
	
	CRPG_Stats_Jobs.sort(4);
}

function clientCmdStats_SetLots(%names, %costs)
{
	CRPG_Stats_Lots.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		%cost	= mFloor(%cost) > 0 ? "$" @ %cost : "None";
		
		if(%name !$= "")
			CRPG_Stats_Lots.addRow(CRPG_Stats_Lots.rowCount(), %name TAB %cost);
	}
}

function clientCmdStats_SetOutfit(%parts, %decal, %nodes, %color)
{
	CRPG_Avatar.parts = %parts;
	CRPG_Avatar.decal = %decal;
	
	for(%i = 0; %i < %parts; %i++)
	{
		CRPG_Avatar.part[%i] = getField(%nodes, %i);
		CRPG_Avatar.color[%i] = getField(%color, %i);
	}
	
	CRPG_Stats.hideAllNodes();
	CRPG_Stats.adjustAvatarNodes();
	CRPG_Stats.adjustAvatarColors();
}

function clientCmdStats_SetVehicles(%names, %costs)
{
	CRPG_Stats_Vehicles.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		%cost	= mFloor(%cost) > 0 ? "$" @ %cost : "None";
		
		if(%name !$= "")
			CRPG_Stats_Vehicles.addRow(CRPG_Stats_Vehicles.rowCount(), %name TAB %cost);
	}
}

function clientCmdStats_SetWeapons(%names, %costs)
{
	CRPG_Stats_Weapons.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		%cost	= mFloor(%cost) > 0 ? "$" @ %cost : "None";
		
		if(%name !$= "")
			CRPG_Stats_Weapons.addRow(CRPG_Stats_Weapons.rowCount(), %name TAB %cost);
	}
}
